@@ -2,12 +2,6 @@
 from __future__ import annotations
 
 
-class WebsocketClosed(Exception):
-    """Raising a clean disconnect to Home Assistant"""
-
-    pass
-
-
 class HiloError(Exception):
     """A base error."""
 
